scxpand.util.train\_util
========================

.. automodule:: scxpand.util.train_util

   
   .. rubric:: Functions

   .. autosummary::
   
      check_early_stopping
      get_lr_scheduler
      get_optimizer
      report_to_optuna_and_handle_pruning
      update_lr_scheduler
   